==> alpha-0.7.5.7-src.tar.bz2: Alpha-0.7.5.7-src/Manah/HotKeyCtrl.h <==
// HotKeyCtrl.h
// (c) 2003-2004 exeal

#ifndef _HOT_KEY_CTRL_H_
#define _HOT_KEY_CTRL_H_
#include "Window.h"


namespace Manah {
namespace Windows {
namespace Controls {

// CHotKeyCtrl class definition
/////////////////////////////////////////////////////////////////////////////

class CHotKeyCtrl : public CWindow {
	// \bh
public:
	bool				Create(DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT nId);
	bool				CreateEx(DWORD dwExStyle, DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT nId);

	DWORD				GetHotKey() const;
	void				GetHotKey(WORD& wVirutalKeyCode, WORD& wModifiers) const;
	const TCHAR*		GetHotKeyName() const;
	static const TCHAR*	GetKeyName(UINT nVirtualKey, bool bExtended);
	void				SetHotKey(WORD wVirtualKeyCode, WORD wModifiers);
	void				SetRules(WORD wInvalidCombination, WORD wModifiers);
};


// CHotKeyCtrl class implementation
/////////////////////////////////////////////////////////////////////////////

inline bool CHotKeyCtrl::Create(DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT nId) {
	return CWindow::Create(false, HOTKEY_CLASS, _T(""),
			dwStyle, rect.left, rect.top, rect.right - rect.left,
			rect.bottom - rect.top, hwndParent, 0, 0L);
}

inline bool CHotKeyCtrl::CreateEx(DWORD dwExStyle, DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT nId) {
	return CWindow::CreateEx(false, dwExStyle, HOTKEY_CLASS, _T(""),
			dwStyle, rect.left, rect.top, rect.right - rect.left,
			rect.bottom - rect.top, hwndParent, 0, 0L);
}

inline DWORD CHotKeyCtrl::GetHotKey() const {
	return const_cast<CHotKeyCtrl*>(this)->SendMessage(HKM_GETHOTKEY);
}

inline void CHotKeyCtrl::GetHotKey(WORD& wVirtualKeyCode, WORD& wModifiers) const {
	const DWORD	dwKeys = const_cast<CHotKeyCtrl*>(this)->SendMessage(HKM_GETHOTKEY);
	wVirtualKeyCode = LOWORD(dwKeys);
	wModifiers = HIWORD(dwKeys);
}

inline const TCHAR* CHotKeyCtrl::GetHotKeyName() const {
	AssertValidAsWindow();
	static TCHAR	szHotKeyName[100];
	WORD			wVKey, wModifiers;

	GetHotKey(wVKey, wModifiers);
	szHotKeyName[0] = 0;
	if(toBoolean(wModifiers & HOTKEYF_CONTROL))	_tcscat(szHotKeyName, _T("Ctrl+"));
	if(toBoolean(wModifiers & HOTKEYF_SHIFT))	_tcscat(szHotKeyName, _T("Shift+"));
	if(toBoolean(wModifiers & HOTKEYF_ALT))		_tcscat(szHotKeyName, _T("Alt+"));
	if(toBoolean(wModifiers & HOTKEYF_EXT))		_tcscat(szHotKeyName, _T("Ext+"));
	_tcscat(szHotKeyName, GetKeyName(wVKey, false));

	return szHotKeyName;
}

inline const TCHAR* CHotKeyCtrl::GetKeyName(UINT nVirtualKey, bool bExtended) {
	static TCHAR	szKeyName[50];
	::GetKeyNameText(
		(::MapVirtualKey(nVirtualKey, 0) << 16) |
		((bExtended ? 1 : 0) << 24), szKeyName, 50);
	return szKeyName;
}

inline void CHotKeyCtrl::SetHotKey(WORD wVirtualKeyCode, WORD wModifiers) {
	SendMessage(HKM_SETHOTKEY, MAKEWORD(wVirtualKeyCode, wModifiers));
}

inline void CHotKeyCtrl::SetRules(WORD wInvalidCombination, WORD wModifiers) {
	SendMessage(HKM_SETRULES, wInvalidCombination, MAKELPARAM(wModifiers, 0));
}

} /* namespace Controls */
} /* namespace Windows */
} /* namespace Manah */

#endif /* _HOT_KEY_CTRL_H_ */

/* [EOF] */

==> alpha-0.7.5.16-src.tar.bz2: Alpha-0.7.5.16-src/Manah/HotKeyCtrl.h <==
// HotKeyCtrl.h
// (c) 2003-2004 exeal

#ifndef _HOT_KEY_CTRL_H_
#define _HOT_KEY_CTRL_H_
#include "Window.h"


namespace Manah {
namespace Windows {
namespace Controls {

// CHotKeyCtrl class definition
/////////////////////////////////////////////////////////////////////////////

class CHotKeyCtrl : public CWindow {
	// \bh
public:
	bool				Create(DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT nId);
	bool				CreateEx(DWORD dwExStyle, DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT nId);

	DWORD				GetHotKey() const;
	void				GetHotKey(WORD& wVirutalKeyCode, WORD& wModifiers) const;
	const TCHAR*		GetHotKeyName() const;
	static const TCHAR*	GetKeyName(UINT nVirtualKey, bool bExtended);
	void				SetHotKey(WORD wVirtualKeyCode, WORD wModifiers);
	void				SetRules(WORD wInvalidCombination, WORD wModifiers);
};


// CHotKeyCtrl class implementation
/////////////////////////////////////////////////////////////////////////////

inline bool CHotKeyCtrl::Create(DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT nId) {
	return CWindow::Create(false, HOTKEY_CLASS, _T(""),
			dwStyle, rect.left, rect.top, rect.right - rect.left,
			rect.bottom - rect.top, hwndParent, 0, 0L);
}

inline bool CHotKeyCtrl::CreateEx(DWORD dwExStyle, DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT nId) {
	return CWindow::CreateEx(false, dwExStyle, HOTKEY_CLASS, _T(""),
			dwStyle, rect.left, rect.top, rect.right - rect.left,
			rect.bottom - rect.top, hwndParent, 0, 0L);
}

inline DWORD CHotKeyCtrl::GetHotKey() const {
	return const_cast<CHotKeyCtrl*>(this)->SendMessage(HKM_GETHOTKEY);
}

inline void CHotKeyCtrl::GetHotKey(WORD& wVirtualKeyCode, WORD& wModifiers) const {
	const DWORD	dwKeys = const_cast<CHotKeyCtrl*>(this)->SendMessage(HKM_GETHOTKEY);
	wVirtualKeyCode = LOWORD(dwKeys);
	wModifiers = HIWORD(dwKeys);
}

inline const TCHAR* CHotKeyCtrl::GetHotKeyName() const {
	AssertValidAsWindow();
	static TCHAR	szHotKeyName[100];
	WORD			wVKey, wModifiers;

	GetHotKey(wVKey, wModifiers);
	szHotKeyName[0] = 0;
	if(toBoolean(wModifiers & HOTKEYF_CONTROL))	std::_tcscat(szHotKeyName, _T("Ctrl+"));
	if(toBoolean(wModifiers & HOTKEYF_SHIFT))	std::_tcscat(szHotKeyName, _T("Shift+"));
	if(toBoolean(wModifiers & HOTKEYF_ALT))		std::_tcscat(szHotKeyName, _T("Alt+"));
	if(toBoolean(wModifiers & HOTKEYF_EXT))		std::_tcscat(szHotKeyName, _T("Ext+"));
	std::_tcscat(szHotKeyName, GetKeyName(wVKey, false));

	return szHotKeyName;
}

inline const TCHAR* CHotKeyCtrl::GetKeyName(UINT nVirtualKey, bool bExtended) {
	static TCHAR	szKeyName[50];
	::GetKeyNameText(
		(::MapVirtualKey(nVirtualKey, 0) << 16) |
		((bExtended ? 1 : 0) << 24), szKeyName, 50);
	return szKeyName;
}

inline void CHotKeyCtrl::SetHotKey(WORD wVirtualKeyCode, WORD wModifiers) {
	SendMessage(HKM_SETHOTKEY, MAKEWORD(wVirtualKeyCode, wModifiers));
}

inline void CHotKeyCtrl::SetRules(WORD wInvalidCombination, WORD wModifiers) {
	SendMessage(HKM_SETRULES, wInvalidCombination, MAKELPARAM(wModifiers, 0));
}

} /* namespace Controls */
} /* namespace Windows */
} /* namespace Manah */

#endif /* _HOT_KEY_CTRL_H_ */

/* [EOF] */
